import React from 'react';
import PropTypes from 'prop-types';

import { ZONE_MANAGER, COMPONENTS } from 'common/ui-labels';

function InProgressRow(props) {
    const { inProgress, lastSyncNumber } = props;
   
    if (!inProgress) {
        return (
            <div className="In-Progress">
                <div className="col-md-3"><i className="fa fa-spinner fa-2x fa-fw" style={{ color: 'green' }} /></div>
                <div className="col-md-6 text-left">{ZONE_MANAGER.DISPLAY.COMPLETE}</div>
            </div>);
    }
    
    return (
        <div className="In-Progress">
            <div className="col-md-3"><i className="fa fa-spinner fa-pulse fa-2x" style={{ color: 'orange' }} /></div>
            <div className="col-md-6 text-left">{ZONE_MANAGER.DISPLAY.IN_PROCESS}</div>
            <div className="col-md-1">{inProgress}/{lastSyncNumber}</div>
        </div>);
}

InProgressRow.propTypes = {
    inProgress: PropTypes.number,
    lastSyncNumber: PropTypes.number,
};

InProgressRow.defaultProps = {
    inProgress: 0,
    lastSyncNumber: 0,
};


export default function VehicleTable(props) {
    const { statuses, lastSyncDate, lastSyncNumber } = props;
    
    return (
        <div className="text-center">
            <div className="Total">
                <div className="col-md-3" />
                <div className="col-md-6 text-left">{COMPONENTS.FIELDS.COMMON.TOTAL}</div>
                <div className="col-md-1">{statuses.total}</div>
            </div>
            <div className="Out-Of-Sync">
                <div className="col-md-3"><i className="fa fa-times-circle fa-2x" /></div>
                <div className="col-md-6 text-left">{ZONE_MANAGER.DISPLAY.OOSYNC}</div>
                <div className="col-md-1">{statuses.outOfSync}</div>
            </div>
            <div className="Outdated">
                <div className="col-md-3"><i className="fas fa-hourglass-end fa-2x" /></div>
                <div className="col-md-6 text-left">{ZONE_MANAGER.DISPLAY.OUTDATED}</div>
                <div className="col-md-1">{statuses.outDated}</div>
            </div>
            <div className="Unresponsive">
                <div className="col-md-3"><i className="fa fa-exclamation-triangle fa-2x" /></div>
                <div className="col-md-6 text-left text-capitalize">{COMPONENTS.FIELDS.COMMON.UNRESPONSIVE}</div>
                <div className="col-md-1">{statuses.unresponsive}</div>
            </div>
            <div className="Updated">
                <div className="col-md-3"><i className="far fa-check-circle fa-2x" /></div>
                <div className="col-md-6 text-left">{ZONE_MANAGER.DISPLAY.UPDATED}</div>
                <div className="col-md-1">{statuses.updated}</div>
            </div>
            <InProgressRow
                inProgress={statuses.inProgress}
                lastSyncNumber={lastSyncNumber}
            />
            <div className="Last-Sync">
                <span className="Last-Sync-Title">{ZONE_MANAGER.DISPLAY.LAST_SYNC}:</span>
                <span>{lastSyncDate}</span>
            </div>
        </div>
    );
}

VehicleTable.propTypes = {
    lastSyncDate: PropTypes.string,
    lastSyncNumber: PropTypes.number,
    statuses: PropTypes.shape({
        total: PropTypes.number,
        outOfSync: PropTypes.number,
        outDated: PropTypes.number,
        inProgress: PropTypes.number,
        updated: PropTypes.number,
        unresponsive: PropTypes.number,
    }),
};

VehicleTable.defaultProps = {
    lastSyncDate: '-',
    lastSyncNumber: 0,
    statuses: {
        total: 0,
        outOfSync: 0,
        outDated: 0,
        inProgress: 0,
        updated: 0,
        unresponsive: 0,
    },
};
