import React, { useEffect } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { injectIntl } from 'react-intl';

import { ZONE_MANAGER, NAMES_OF_TABS } from 'common/ui-labels';

import VehicleTrackableTable from './VehicleTrackableTable';
import VehicleStatusTable from './VehicleStatusTable';
import { getLastSyncTransaction, loadZoneDownloadStatus } from '../store/actions';
import { getFormattedTrackables, getLastSyncDate, getLastSyncNumber, defineStatusCount } from '../utils';


function VehicleTab(props) {
    const { trackables, statuses, lastSyncDate, lastSyncNumber } = props;
    
    useEffect(() => {
        props.dispatch(loadZoneDownloadStatus());
        props.dispatch(getLastSyncTransaction());
    }, []);
    
    return (
        <section className="AppLayout-Admin-Tab" style={{ padding: '0 15px' }}>
            <h3 className="text-center AdminTab-Title">{NAMES_OF_TABS.ZONE_MANAGEMENT}</h3>
            <hr />
            <div className="row">
                <div className="col-md-12">
                    <VehicleTrackableTable trackables={trackables} />
                    <div className="Vehicle-Status-Table">
                        <h4 className="text-center AdminTab-Title">{ZONE_MANAGER.HEADER}</h4>
                        <VehicleStatusTable statuses={statuses} lastSyncDate={lastSyncDate} lastSyncNumber={lastSyncNumber} />
                    </div>
                </div>
            </div>
        </section>);
}

VehicleTab.propTypes = {
    trackables: PropTypes.shape(),
    lastSyncDate: PropTypes.string,
    lastSyncNumber: PropTypes.number,
    dispatch: PropTypes.func,
    statuses: PropTypes.shape({
        total: PropTypes.number,
        outOfSync: PropTypes.number,
        outDated: PropTypes.number,
        inProgress: PropTypes.number,
        updated: PropTypes.number,
        unresponsive: PropTypes.number,
    }),
};

VehicleTab.defaultProps = {
    trackables: new Map(),
    lastSyncDate: '',
    lastSyncNumber: 0,
    dispatch: () => {},
    statuses: {
        total: 0,
        outOfSync: 0,
        outDated: 0,
        inProgress: 0,
        updated: 0,
        unresponsive: 0,
    },
};

const mapStateToProps = (state) => {
    const trackables = getFormattedTrackables(state);
    return {
        trackables,
        statuses: defineStatusCount(trackables),
        lastSyncDate: getLastSyncDate(state),
        lastSyncNumber: getLastSyncNumber(state),
    };
};

export default connect(mapStateToProps)(injectIntl(VehicleTab));
