import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { injectIntl } from 'react-intl';

import { TABLES, ZONE_MANAGER } from 'common/ui-labels';
import { refreshStatuses, syncStatuses } from '../../store/actions';

class TableButtons extends React.Component {
    static propTypes = {
        setFilterItems: PropTypes.func,
        width: PropTypes.number,
        disableActions: PropTypes.bool,
        items: PropTypes.arrayOf(PropTypes.shape()),
        selectedItems: PropTypes.arrayOf(PropTypes.shape()),
        searchFields: PropTypes.arrayOf(PropTypes.string),
        dispatch: PropTypes.func,
        intl: PropTypes.shape({
            formatMessage: PropTypes.func,
        }),
    };
    
    static defaultProps = {
        setFilterItems: () => {
        },
        width: 1000,
        disableActions: false,
        items: [],
        selectedItems: [],
        searchFields: [],
        dispatch: () => {
        },
        intl: {
            formatMessage: () => {
            },
        },
    };
    
    constructor(props) {
        super(props);
        
        this.timeout = null;
    }
    
    refreshSelected = () => {
        if (this.props.selectedItems && this.props.selectedItems.length > 0) {
            this.props.dispatch(refreshStatuses(this.props.selectedItems));
        }
    };
    
    syncSelected = () => {
        if (this.props.selectedItems && this.props.selectedItems.length > 0) {
            this.props.dispatch(syncStatuses(this.props.selectedItems));
        }
    };
    
    syncAll = () => {
        this.props.dispatch(syncStatuses(this.props.items));
    };

    createAddDeleteBtn = () => (
        <section className="Table-Buttons">
            <button
                type="button"
                disabled={this.props.disableActions}
                data-id="vehicle-sync-checked-button"
                onClick={this.syncSelected}
            >
                {ZONE_MANAGER.SYNC_SELECTED}
            </button>
        
            <button
                type="button"
                disabled={this.props.disableActions}
                data-id="vehicle-sync-all-button"
                onClick={this.syncAll}
            >
                {ZONE_MANAGER.SYNC_ALL}
            </button>
        
            <button
                type="button"
                disabled={this.props.disableActions}
                data-id="vehicle-refresh-checked-button"
                onClick={this.refreshSelected}
            >
                {ZONE_MANAGER.REFRESH_SELECTED}
            </button>
        </section>
    );
    
    createCustomSearchField = () => (
        <input
            type="text"
            className="form-control input-sm"
            placeholder={TABLES.SEARCH(this.props.intl)}
            onChange={(e) => {
                const value = e.target.value;
                const regex = new RegExp(value, 'i');
                clearTimeout(this.timeout);
                
                this.timeout = setTimeout(() => {
                    const filteredItems = [...this.props.items.values()]
                        .filter(item => this.props.searchFields.some(field => item[field].match(regex)));
                    this.props.setFilterItems(filteredItems, !!(value && value.length));
                }, 600);
            }}
        />
    );

    render() {
        return (
            <div className="row" style={{ width: this.props.width, marginBottom: '20px' }}>
                <div className="col-md-8">{this.createAddDeleteBtn()}</div>
                <div className="col-md-4 text-right">
                    <div style={{ marginRight: '-30px' }}>{this.createCustomSearchField()}</div>
                </div>
            </div>
        );
    }
}

export default connect()(injectIntl(TableButtons));
