import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { SortDirection, AutoSizer } from 'react-virtualized';

import LoadTable from './LoadTable';
import { hasInProgressStatus } from './../../utils';


class VehicleTrackableTable extends Component {
    static propTypes = {
        dispatch: PropTypes.func,
        dataIsLoaded: PropTypes.bool,
        trackables: PropTypes.shape(),
        selectedTrackables: PropTypes.arrayOf(PropTypes.shape()),
    };
    
    static defaultProps = {
        dispatch: () => {},
        dataIsLoaded: false,
        trackables: new Map(),
        selectedTrackables: [],
    };
    
    constructor(props) {
        super(props);

        this.state = {
            updateProcessRunning: false,
            containerWidth: 0,
            containerHeight: 0,
        };
    }
    
    static getDerivedStateFromProps(props, state) {
        if (hasInProgressStatus(props.trackables) && !state.updateProcessRunning) {
            return {
                updateProcessRunning: true,
            };
        }
        if (!hasInProgressStatus(props.trackables) && state.updateProcessRunning) {
            return {
                updateProcessRunning: false,
            };
        }
        return null;
    }
    
    render() {
        const { trackables, dispatch, selectedTrackables, dataIsLoaded } = this.props;
        const { containerWidth, containerHeight } = this.state;

        return (
            <section className="vehicle-trackable-table">
                <AutoSizer
                    onResize={({ height, width }) => {
                        this.setState({
                            containerWidth: width,
                            containerHeight: height,
                        });
                    }}
                    style={{ width: '100%' }}
                >
                    {({ height, width }) => (
                        <Fragment>
                            <LoadTable
                                tableProps={{
                                    disableActions: this.state.updateProcessRunning,
                                    selectedItems: selectedTrackables,
                                    totalCount: trackables.size,
                                    allItems: trackables,
                                    tableSize: {
                                        width: containerWidth,
                                        height: containerHeight,
                                        headerHeight: 40,
                                        rowHeight: 40,
                                    },
                                    dispatch,
                                    defaultSortName: 'download_status_display',
                                    defaultSortOrder: SortDirection.DESC,
                                }}
                                dataIsLoaded={dataIsLoaded}
                            />
                        </Fragment>
                    )}
                </AutoSizer>
            </section>
        );
    }
}

const mapStateToProps = state => (
    {
        selectedTrackables: state.adminPage.selectedItems,
        dataIsLoaded: state.zoneManager.zoneDownloadStatus.loaded,
    }
);

export default connect(mapStateToProps)(VehicleTrackableTable);
