import { ACTIONS, NOTIFY_ACTIONS } from '../../common/constants';

const initialState = {
    byUid: {},
    loaded: false,
    lastSyncTransaction: null,
};

const zoneDownloadStatus = (state = initialState, action) => {
    switch (action.type) {
        case ACTIONS.ZONE_DOWNLOAD_STATUS_SET: {
            const newState = { ...state, byUid: {} };
            action.params.forEach((zone_status) => {
                newState.byUid[zone_status.trackable_uid] = zone_status;
            });
            return newState;
        }
        case NOTIFY_ACTIONS.ZONE_DOWNLOAD_STATUS_CREATED: {
            const newState = { ...state };
            if (Array.isArray(action.params)) {
                action.params.forEach((zone_status) => {
                    newState.byUid[zone_status.trackable_uid] = zone_status;
                });
            } else if (action.params && action.params.trackable_uid) {
                newState.byUid[action.params.trackable_uid] = action.params;
            }
            return newState;
        }
        case ACTIONS.ZONE_DOWNLOAD_STATUS_LOADED:
            return {
                ...state,
                loaded: true,
            };
        case NOTIFY_ACTIONS.ZONE_DOWNLOAD_STATUS_DELETED: {
            const newState = { ...state };
            delete newState.byUid[action.params.trackable_uid];
            return newState;
        }
        case ACTIONS.ZONE_DOWNLOAD_TRANSACTION_SET: {
            return { ...state, lastSyncTransaction: action.params };
        }
        case NOTIFY_ACTIONS.ZONE_DOWNLOAD_TRANSACTION_CREATED: {
            return { ...state, lastSyncTransaction: action.params.transaction };
        }
        case ACTIONS.ZONE_DOWNLOAD_STATUS_CLEAR:
            return { ...initialState };
        default:
            return state;
    }
};

export default zoneDownloadStatus;
