#!/usr/bin/env bash
set -x #echo on

PROJECT=rtls-addon-zone-manager

RPM_DESCRIPTION="Redpoint Positioning RTLS Addon Zone Manager"
RPM_MAINTAINER=help@redpointpositioning.com
RPP_VENDOR="Redpoint Positioning, Inc."

PROJECT_HOME=${WORKSPACE}

export PATH=/usr/local/bin:/usr/local/rbenv/shims:$PATH

VERSION="$( server/addons/zone_manager/sys-services/rtls-get-version.sh )"
RELEASE="$( server/addons/zone_manager/sys-services/rtls-get-release.sh )"
FILE="$( server/addons/zone_manager/sys-services/rtls-get-file-name.sh )"

echo "PROJECT_HOME:       ${PROJECT_HOME}"
echo "BUILDING ON BRANCH: ${BRANCH_NAME}"
echo "VERSION:            ${VERSION}"
echo "RELEASE:            ${RELEASE}"
echo "FILE:               ${FILE}"

rm -f "${PROJECT_HOME}"/*.deb
rm -f "${PROJECT_HOME}"/*.rpm
[ -d "${PROJECT_HOME}"/releases ] && rm -f "${PROJECT_HOME}"/releases/*

fpm -s dir -t deb -f \
	--description "${RPM_DESCRIPTION}" \
	--maintainer  "${RPM_MAINTAINER}" \
	--vendor "${RPP_VENDOR}" \
	--license "Proprietary" \
	--provides "rtls-addon-zone-manager" \
	--exclude ".git" \
	--rpm-use-file-permissions --rpm-user rtls --rpm-group rtls \
	--before-remove server/addons/zone_manager/sys-services/pre-uninstall.sh \
  --before-install server/addons/zone_manager/sys-services/pre-install.sh \
  --after-install server/addons/zone_manager/sys-services/post-install.sh \
  --before-upgrade server/addons/zone_manager/sys-services/pre-update.sh \
  --after-upgrade server/addons/zone_manager/sys-services/post-update.sh \
  --after-remove server/addons/zone_manager/sys-services/after-remove.sh \
	--depends "nodejs (>= 20.5.1)" \
  --depends 'rtls-frontend >= 2023.3.722' \
  --depends 'rtls-server >= 2023.3.725' \
  --depends 'jq' \
  --deb-group rtls \
  --deb-user rtls \
  --name "${PROJECT}" \
	--version "${VERSION}" \
	--iteration "${RELEASE}" \
	--package "${PROJECT_HOME}" \
	./server/addons/zone_manager.js=/usr/rtls/rtls-frontend/server/addons/zone_manager.js \
  ./server/addons/zone_manager/=/usr/rtls/rtls-frontend/server/addons/zone_manager \
	./client/addons/zone_manager.js=/usr/rtls/rtls-frontend/client/addons/zone_manager.js \
  ./client/addons/zone_manager/=/usr/rtls/rtls-frontend/client/addons/zone_manager \
