const logger = require('../../../utils/logger/index');
const api = require('./index');
const Service = require('./service');
const { TYPE_ACTION } = require('enums').OBJECT_TYPE;


async function sendZoneDownloadRequest(req, res, next) {
    try {
        const { trackables, action } = req.body.zone_download_request;
        const { valid_zone_download_array, tko_uids_exist, tko_uids_not_exist } = await api.splitZoneDownloadListByExistence(trackables);
        const plist = { zone_download_request: valid_zone_download_array };

        if (action.toUpperCase() === TYPE_ACTION.VERIFY.toUpperCase()) {
            Service.handleDownloadRequestVerify(req, plist);
        } else {
            await Service.handleDownloadRequestUpdate(req, valid_zone_download_array, plist);
        }
        res.status(200).json({
            message: (tko_uids_exist && tko_uids_exist.length > 0 ? `The following entities were successfully processed: [${tko_uids_exist}]. ` : '') +
                (tko_uids_not_exist && tko_uids_not_exist.length > 0 
                    ? `The following entities are invalid and were not processed: [${tko_uids_not_exist}].` : ''),
        });
    } catch (err) {
        logger.error('[sendZoneDownloadRequest] error: ', err);
        next(err);
    }
}

async function getLastTransaction(req, res, next) {
    try {
        const project = req.scope.projectTag;
        const zone_download_transaction = await api.getSyncTransactionForProject(project.uid);
        res.send({ zone_download_transaction });
    } catch (err) {
        logger.error('[getLastTransaction] error: ', err);
        next(err);
    }
}

module.exports = {
    getLastTransaction,
    sendZoneDownloadRequest,
};
