const error = require('http-errors');
const logger = require('../../../utils/logger/index');
const UID = require('./../../../routes/arrayfunctions').getUUID;
const { ZoneDownloadRequestRepo } = require('../repository/zone_download_request');


async function saveSyncRequestTransaction(trackable_uids = [], project) {
    if (!Array.isArray(trackable_uids) || trackable_uids.length === 0) {
        return null;
    }
    const transaction = {
        created_at: new Date(),
        uid: UID(),
        trackable_uids: trackable_uids.join(','),
        project_uid: project.uid || null,
    };

    await ZoneDownloadRequestRepo.insertStatus(transaction);

    return transaction;
}

async function updateTrackableSyncRequestStatus(trackable_uids = [], sync_requested) {
    if (!Array.isArray(trackable_uids) || trackable_uids.length === 0) {
        return null;
    }
    await ZoneDownloadRequestRepo.updateStatus(sync_requested, trackable_uids);

    return ZoneDownloadRequestRepo.getStatuses(trackable_uids);
}

async function getSyncTransactionForProject(project_uid) {
    if (!project_uid) {
        logger.error('Project is not specified');
        throw error(422, 'Project is not specified');
    }
    return ZoneDownloadRequestRepo.getTransaction(project_uid);
}

async function splitZoneDownloadListByExistence(zone_download_list) {
    const tko_uids = zone_download_list.map(item => item.trackable_uid);
    const tko_uids_exist = (await ZoneDownloadRequestRepo.getValidTrackables(tko_uids)).map(x => x.uid);
    const tko_uids_not_exist = [];
    const valid_zone_download_array = [];
    zone_download_list.forEach((item) => {
        if (tko_uids_exist.find(uid => uid === item.trackable_uid)) {
            valid_zone_download_array.push(item);
        } else {
            tko_uids_not_exist.push(item.trackable_uid);
        }
    });

    if (tko_uids_exist.length === 0) {
        logger.error(`splitZoneDownloadListByExistence. Trackables [${tko_uids_not_exist}] don't exist`);
        throw error(422, `Trackables [${tko_uids_not_exist}] don't exist`);
    }

    return {
        valid_zone_download_array,
        tko_uids_exist,
        tko_uids_not_exist,
    };
}


module.exports = {
    saveSyncRequestTransaction,
    getSyncTransactionForProject,
    updateTrackableSyncRequestStatus,
    splitZoneDownloadListByExistence,
};
