const ZMQUtils = require('./../../../routes/utils_zmq');
const api = require('./index');
const { ZMQ_OBJECT, TYPE_ACTION } = require('enums').OBJECT_TYPE;


const ZONE_MANAGER_TRIPLE_TIMEOUT = 30000;

function InitCheckTimout(trackable_uids, req) {
    setTimeout(async () => {
        const sync_requested = false;
        const statuses = await api.updateTrackableSyncRequestStatus(trackable_uids, sync_requested);
        ZMQUtils.notify({
            req: { user: { ...req.user }, scope: { ...req.scope }, remoteIPdetected: req.remoteIPdetected },
            object: ZMQ_OBJECT.ZONE_DOWNLOAD_STATUS,
            action: TYPE_ACTION.CREATED,
            plist: statuses,
        });
    }, ZONE_MANAGER_TRIPLE_TIMEOUT);
}

async function handleDownloadRequestUpdate(req, trackables, plist) {
    const project = req.scope && req.scope.projectTag;
    const sync_requested = true;
    const trackable_uids = trackables.map(tko => tko.trackable_uid);
    const transaction = await api.saveSyncRequestTransaction(trackable_uids, project);
    const statuses = await api.updateTrackableSyncRequestStatus(trackable_uids, sync_requested);
    
    InitCheckTimout(trackable_uids, req);
    
    ZMQUtils.notify({
        req,
        object: ZMQ_OBJECT.ZONE_DOWNLOAD_TRANSACTION,
        action: TYPE_ACTION.CREATED,
        plist: {
            transaction,
        },
    });
    
    ZMQUtils.notify({
        req,
        object: ZMQ_OBJECT.ZONE_DOWNLOAD_STATUS,
        action: TYPE_ACTION.CREATED,
        plist: statuses,
    });
    
    ZMQUtils.notify({
        req,
        object: ZMQ_OBJECT.ZONE_DOWNLOAD_REQUEST,
        action: TYPE_ACTION.UPDATE,
        plist,
    });
}

function handleDownloadRequestVerify(req, plist) {
    ZMQUtils.notify({
        req,
        object: ZMQ_OBJECT.ZONE_DOWNLOAD_REQUEST,
        action: TYPE_ACTION.VERIFY,
        plist,
    });
}


module.exports = {
    handleDownloadRequestUpdate,
    handleDownloadRequestVerify,
};
