const error = require('http-errors');
const logger = require('../../../utils/logger/index');
const api = require('./index');
const zdrApi = require('../zone_download_request/index');
const Service = require('./service');


async function getZoneDownloadStatusHandler(req, res, next) {
    try {
        const queryString = req.query;
        const trackable_uid = req.params.uid;
        const zone_download_status = await api.getZoneDownloadStatus(trackable_uid, queryString);
        res.json({ zone_download_status });
    } catch (err) {
        logger.error('[getZoneDownloadStatusHandler] error: ', err);
        next(err);
    }
}

async function deleteZoneDownloadStatus(req, res, next) {
    try {
        const trackable_uid = req.params.uid;
        await Service.deleteDownloadStatus(req, trackable_uid);
        res.status(204).end();
    } catch (err) {
        logger.error('[deleteZoneDownloadStatus] error: ', err);
        next(err);
    }
}

async function setZoneDownloadStatusHandler(req, res, next) {
    try {
        logger.verbose('[setZoneDownloadStatusHandler] req.data %j', req.data);
        const { zone_download_status } = req.data;
        const { valid_zone_download_array, tko_uids_exist, tko_uids_not_exist } = await zdrApi.splitZoneDownloadListByExistence(zone_download_status);
        const download_status_list = await Service.saveDownloadStatus(req, valid_zone_download_array);
        
        if (tko_uids_exist.length === 0 && tko_uids_not_exist.length > 0) {
            logger.error(`setZoneDownloadStatus. Trackables [${tko_uids_not_exist}] don't exist`);
            throw error(422, `Trackables [${tko_uids_not_exist}] don't exist`);
        }

        res.json({
            message: (tko_uids_exist.length > 0 ? `The following entities were successfully processed: [${tko_uids_exist}]. ` : '') +
                (tko_uids_not_exist.length > 0 ? `The following entities are invalid and were not processed: [${tko_uids_not_exist}].` : ''),
            zone_download_status: download_status_list,
        });
    } catch (err) {
        logger.error('[setZoneDownloadStatusHandler] error: ', err);
        next(err);
    }
}

module.exports = {
    getZoneDownloadStatusHandler,
    setZoneDownloadStatusHandler,
    deleteZoneDownloadStatus,
};
