const logger = require('../../../utils/logger/index');
const { ZoneDownloadStatusRepo } = require('../repository/zone_download_status');


function getProjectStatusMap(status_values = [], trackables_projects = []) {
    const statusMap = new Map();
    status_values.forEach((status) => {
        const tko_project = trackables_projects.find(trackable_project => trackable_project.uid === status.trackable_uid);
        const project = statusMap.get(tko_project.project_uid);
        if (!project) {
            statusMap.set(tko_project.project_uid, [status]);
        } else {
            project.push(status);
        }
    });
    return statusMap;
}

function getUniqueStatusList(zone_download_statuses = []) {
    const statuses = zone_download_statuses.reduce((memo, status) => {
        if (status.trackable_uid) {
            memo.set(status.trackable_uid, status);
        }
        return memo;
    }, new Map());
    
    return { status_list: [...statuses.values()], trackable_uids: [...statuses.keys()] };
}

async function getDataForProjects(trackable_uids, status_list) {
    // Get projects for all updated trackables for ws notify
    const trackables_projects = await ZoneDownloadStatusRepo.getTrackablesProjects(trackable_uids);
    const filtered_status_values = [];
    const formatted_status_list = status_list.reduce((memo, status) => {
        const statusTrackableHasProject = trackables_projects.find(tko_project => tko_project.uid === status.trackable_uid);
        if (statusTrackableHasProject) {
            memo.push([status.trackable_uid, status.download_status, status.reason]);
            filtered_status_values.push(status);
        }
        return memo;
    }, []);
    
    return {
        formatted_status_list,
        filtered_status_values,
        trackables_projects,
    };
}

function getZoneDownloadStatus(trackable_uid, queryString) {
    return ZoneDownloadStatusRepo.getZoneDownloadStatus(trackable_uid, queryString);
}

async function removeZoneDownloadStatus(trackable_uid) {
    const trackable = await ZoneDownloadStatusRepo.getTrackableWithProject(trackable_uid);
    if (trackable) {
        await ZoneDownloadStatusRepo.deleteStatusByTrackable(trackable_uid);
        return {
            trackable,
            project_uid: trackable.project_uid,
        };
    }
    return {};
}

async function setZoneDownloadStatus(zone_download_statuses = []) {
    logger.verbose('[setZoneDownloadStatus] zone_download_statuses: ', zone_download_statuses);
    const { status_list, trackable_uids } = getUniqueStatusList(zone_download_statuses);
    
    if (status_list.length > 0) {
        const { formatted_status_list, filtered_status_values, trackables_projects } = await getDataForProjects(trackable_uids, status_list);
        
        if (formatted_status_list && formatted_status_list.length > 0) {
            await ZoneDownloadStatusRepo.upsertStatus(formatted_status_list);
        }
        
        return getProjectStatusMap(filtered_status_values, trackables_projects);
    }
    return new Map();
}

module.exports = {
    getUniqueStatusList,
    getProjectStatusMap,
    getDataForProjects,
    getZoneDownloadStatus,
    setZoneDownloadStatus,
    removeZoneDownloadStatus,
};
