const { notify } = require('./../../../routes/utils_zmq');
const api = require('./index');
const { ZMQ_OBJECT, TYPE_ACTION } = require('enums').OBJECT_TYPE;

function addProjectUidToReq(req, project_uid) {
    return { ...req, scope: { projectTag: { uid: project_uid } } };
}


async function saveDownloadStatus(req, zone_download_status) {
    const statusMap = await api.setZoneDownloadStatus(zone_download_status);
    const download_status_list = [];
    
    statusMap.forEach((statuses, project_uid) => {
        download_status_list.push(...statuses);
        notify({
            req: addProjectUidToReq(req, project_uid),
            object: ZMQ_OBJECT.ZONE_DOWNLOAD_STATUS,
            action: TYPE_ACTION.CREATED,
            plist: statuses,
        });
    });
    
    return download_status_list;
}

async function deleteDownloadStatus(req, trackable_uid) {
    const { trackable, project_uid } = await api.removeZoneDownloadStatus(trackable_uid);
    if (trackable) {
        notify({
            req: addProjectUidToReq(req, project_uid),
            object: ZMQ_OBJECT.ZONE_DOWNLOAD_STATUS,
            action: TYPE_ACTION.DELETED,
            plist: {
                trackable_uid: trackable.uid,
            },
        });
    }
    
    return undefined;
}


module.exports = {
    saveDownloadStatus,
    deleteDownloadStatus,
};
